/****************************************************************************
** Meta object code from reading C++ file 'dataretriever.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/syndication-17.12.3/src/syndication/dataretriever.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dataretriever.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Syndication__DataRetriever_t {
    QByteArrayData data[5];
    char stringdata0[55];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Syndication__DataRetriever_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Syndication__DataRetriever_t qt_meta_stringdata_Syndication__DataRetriever = {
    {
QT_MOC_LITERAL(0, 0, 26), // "Syndication::DataRetriever"
QT_MOC_LITERAL(1, 27, 13), // "dataRetrieved"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 4), // "data"
QT_MOC_LITERAL(4, 47, 7) // "success"

    },
    "Syndication::DataRetriever\0dataRetrieved\0"
    "\0data\0success"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Syndication__DataRetriever[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QByteArray, QMetaType::Bool,    3,    4,

       0        // eod
};

void Syndication::DataRetriever::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DataRetriever *_t = static_cast<DataRetriever *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->dataRetrieved((*reinterpret_cast< const QByteArray(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (DataRetriever::*_t)(const QByteArray & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DataRetriever::dataRetrieved)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Syndication::DataRetriever::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Syndication__DataRetriever.data,
      qt_meta_data_Syndication__DataRetriever,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Syndication::DataRetriever::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Syndication::DataRetriever::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Syndication__DataRetriever.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Syndication::DataRetriever::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Syndication::DataRetriever::dataRetrieved(const QByteArray & _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_Syndication__OutputRetriever_t {
    QByteArrayData data[6];
    char stringdata0[84];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Syndication__OutputRetriever_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Syndication__OutputRetriever_t qt_meta_stringdata_Syndication__OutputRetriever = {
    {
QT_MOC_LITERAL(0, 0, 28), // "Syndication::OutputRetriever"
QT_MOC_LITERAL(1, 29, 12), // "slotFinished"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 8), // "exitCode"
QT_MOC_LITERAL(4, 52, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(5, 73, 10) // "exitStatus"

    },
    "Syndication::OutputRetriever\0slotFinished\0"
    "\0exitCode\0QProcess::ExitStatus\0"
    "exitStatus"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Syndication__OutputRetriever[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int, 0x80000000 | 4,    3,    5,

       0        // eod
};

void Syndication::OutputRetriever::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        OutputRetriever *_t = static_cast<OutputRetriever *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotFinished((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject Syndication::OutputRetriever::staticMetaObject = {
    { &DataRetriever::staticMetaObject, qt_meta_stringdata_Syndication__OutputRetriever.data,
      qt_meta_data_Syndication__OutputRetriever,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Syndication::OutputRetriever::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Syndication::OutputRetriever::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Syndication__OutputRetriever.stringdata0))
        return static_cast<void*>(this);
    return DataRetriever::qt_metacast(_clname);
}

int Syndication::OutputRetriever::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DataRetriever::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_Syndication__FileRetriever_t {
    QByteArrayData data[14];
    char stringdata0[149];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Syndication__FileRetriever_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Syndication__FileRetriever_t qt_meta_stringdata_Syndication__FileRetriever = {
    {
QT_MOC_LITERAL(0, 0, 26), // "Syndication::FileRetriever"
QT_MOC_LITERAL(1, 27, 20), // "permanentRedirection"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 3), // "url"
QT_MOC_LITERAL(4, 53, 11), // "slotTimeout"
QT_MOC_LITERAL(5, 65, 8), // "slotData"
QT_MOC_LITERAL(6, 74, 9), // "KIO::Job*"
QT_MOC_LITERAL(7, 84, 3), // "job"
QT_MOC_LITERAL(8, 88, 4), // "data"
QT_MOC_LITERAL(9, 93, 10), // "slotResult"
QT_MOC_LITERAL(10, 104, 5), // "KJob*"
QT_MOC_LITERAL(11, 110, 24), // "slotPermanentRedirection"
QT_MOC_LITERAL(12, 135, 7), // "fromUrl"
QT_MOC_LITERAL(13, 143, 5) // "toUrl"

    },
    "Syndication::FileRetriever\0"
    "permanentRedirection\0\0url\0slotTimeout\0"
    "slotData\0KIO::Job*\0job\0data\0slotResult\0"
    "KJob*\0slotPermanentRedirection\0fromUrl\0"
    "toUrl"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Syndication__FileRetriever[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   42,    2, 0x09 /* Protected */,
       5,    2,   43,    2, 0x08 /* Private */,
       9,    1,   48,    2, 0x08 /* Private */,
      11,    3,   51,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QUrl,    3,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QByteArray,    7,    8,
    QMetaType::Void, 0x80000000 | 10,    7,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QUrl, QMetaType::QUrl,    7,   12,   13,

       0        // eod
};

void Syndication::FileRetriever::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FileRetriever *_t = static_cast<FileRetriever *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->permanentRedirection((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 1: _t->slotTimeout(); break;
        case 2: _t->slotData((*reinterpret_cast< KIO::Job*(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 3: _t->slotResult((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 4: _t->slotPermanentRedirection((*reinterpret_cast< KIO::Job*(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2])),(*reinterpret_cast< const QUrl(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (FileRetriever::*_t)(const QUrl & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FileRetriever::permanentRedirection)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Syndication::FileRetriever::staticMetaObject = {
    { &DataRetriever::staticMetaObject, qt_meta_stringdata_Syndication__FileRetriever.data,
      qt_meta_data_Syndication__FileRetriever,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Syndication::FileRetriever::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Syndication::FileRetriever::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Syndication__FileRetriever.stringdata0))
        return static_cast<void*>(this);
    return DataRetriever::qt_metacast(_clname);
}

int Syndication::FileRetriever::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DataRetriever::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Syndication::FileRetriever::permanentRedirection(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
